Index: hello.php
--- hello.php Base (BASE)
+++ hello.php Locally Modified (Based On LOCAL)
@@ -56,8 +56,8 @@
 	echo "<p id='dolly'>$chosen</p>";
 }
 
-// Now we set that function up to execute when the admin_footer action is called
-add_action('admin_footer', 'hello_dolly');
+// Now we set that function up to execute when the admin_notices action is called
+add_action('admin_notices', 'hello_dolly');
 
 // We need some CSS to position the paragraph
 function dolly_css() {
@@ -67,11 +67,10 @@
 	echo "
 	<style type='text/css'>
 	#dolly {
-		position: absolute;
-		top: 4.5em;
+                float:right;
+                padding-$x:15px;
+                padding-top:5px;		
 		margin: 0;
-		padding: 0;
-		$x: 215px;
 		font-size: 11px;
 	}
 	</style>
